from http.client import HTTPResponse
from django.apps import AppConfig
from django.http import Http404, HttpResponse, HttpResponseBadRequest, response
from django.urls import Resolver404
from django.views.generic import TemplateView, ListView
from django.views import View
from django.template import Template, context, loader
from django.http import HttpResponseRedirect
from django.shortcuts import render
from .forms import MainSearchForm

class IndexView(TemplateView):
    """
    The index page of the gawa app.

    Utilizes a generic view, because I will do so for all views, 
    a regular view function would suffice.
    """

    template_name: str = "start/index.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["MainSearchForm"] = MainSearchForm()
        return context

class LegalInfoView(TemplateView):
    """
    Legal info that the german authorities want.
    """

    template_name: str = "start/legalinfo.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["MainSearchForm"] = MainSearchForm()
        return context

class MainSearchView(TemplateView):
    """
    Search for anything.
    """

    template_name: str = "start/search.html"

    def get(self, request, *args, **kwargs):
        form = MainSearchForm(request.GET)
        if not form.is_valid():
            return render(request, "errors/bad_request.html")
        context = {
                "searchstr": form.cleaned_data['search'],
                "MainSearchForm": MainSearchForm()
        }
        return render(request=request, template_name=self.template_name, context=context)
